# Harmonic Mean Iteratively Reweighted Least Squares for Low-Rank Matrix Recovery

This repository contains python code to implement a basic variant of the Harmonic Mean Iteratively Reweighted Least Squares (HM-IRLS) algorithm for low-rank matrix recovery, in particular for the low-rank matrix completion problem, described in the paper:

> C. Kümmerle, J. Sigl.
> "Harmonic Mean Iteratively Reweighted Least Squares for Low-Rank Matrix Recovery", Journal of Machine Learning Research (JMLR) volume 19, number 47, pages 1-49, 2018.
> Available online: https://jmlr.org/papers/volume19/17-244/17-244.pdf

## Version history
* Version 0.0.1, 10/25/2020

## Author
Kristof Schröder

## Documentation
> https://hmirls.readthedocs.io/en/latest/